#loading all the packages
library(Rmisc)
library(tidyverse)
library(reshape2)
library(plyr)
library(effsize)
library(BayesFactor)
library(ggpubr)
library(MBESS)

DATA <- read.csv(file = "Stage_2_DATA_personality_aggregated.csv") #importing data
DATA$MostCat <- as.factor(DATA$MostCat) #choice of favourite colour
DATA$LeastCat <- as.factor(DATA$LeastCat) #choice of least favourite colour


# Planned comparisons and descriptive statistics of colour preferences and personality traits

P_matrix <- expand.grid(number = seq(1:17)) #creating a matrix where results will be included
P_matrix$colour <- c("Red", "Orange", "Yellow", "Green", "Turquoise", 
                    "Turquoise", "Turquoise", "Turquoise","Blue","Pink", 
                    "Pink", "Brown", "Brown", "White", "White",
                    "Grey", "Black")

P_matrix$personality <- c("Extraversion", "Extraversion", "Extraversion", "Agreeableness", "Agreeableness",
                          "Extraversion", "Originality", "Resilience", "Originality", "Agreeableness",
                          "Extraversion", "Conscientiousness", "Extraversion", "Conscientiousness", "Originality",
                         "Resilience", "Originality")

P_matrix$Most_n <- NA
P_matrix$Most_mean <- NA
P_matrix$Most_CI <- NA
P_matrix$Most_CI_lower <- NA
P_matrix$Most_CI_higher <- NA
P_matrix$Not_Most_n <- NA
P_matrix$Not_Most_mean <- NA
P_matrix$Not_Most_CI <- NA
P_matrix$Not_Most_CI_lower <- NA
P_matrix$Not_Most_CI_higher <- NA
P_matrix$t_value <- NA
P_matrix$d_value <- NA
P_matrix$d_CI <- NA
P_matrix$d_CI_lower <- NA
P_matrix$d_CI_higher <- NA
P_matrix$p_value <- NA
P_matrix$BF_01 <- NA
P_matrix$BF_10 <- NA

#calculating descriptive statistics (mean, n, CI) and t-tests

for (current_number in P_matrix$number) {
  current_colour <- P_matrix[which(P_matrix$number == current_number),]$colour #choosing a colour of interest
  current_p <- P_matrix[which(P_matrix$number == current_number),]$personality #choosing a personality dimension of interest
  
  #most (ie participants who chose a particular colour as favourite)
  P_matrix[which(P_matrix$number == current_number),]$Most_mean <- mean(DATA[which(DATA$MostCat == current_colour),
                                                                             which(names(DATA) == current_p)]) #calculating mean values of a particular personality dimension
  P_matrix[which(P_matrix$number == current_number),]$Most_n <- length(DATA[which(DATA$MostCat == current_colour),
                                                                          which(names(DATA) == current_p)]) #extracting the number of participants who chose this colour as favourite
  CI1 <- CI(DATA[which(DATA$MostCat == current_colour), which(names(DATA) == current_p)]) # package Rmisc to calculate confidence intervals of the means of personality dimensions
  P_matrix[which(P_matrix$number == current_number),]$Most_CI_lower <- CI1[3]
  P_matrix[which(P_matrix$number == current_number),]$Most_CI_higher <- CI1[1]
  
  #not most (ie participants who did not choose a particular colour as favourite)
  P_matrix[which(P_matrix$number == current_number),]$Not_Most_mean <- mean(DATA[which(DATA$MostCat != current_colour),
                                                                             which(names(DATA) == current_p)]) #calculating mean values of a particular personality dimension
  P_matrix[which(P_matrix$number == current_number),]$Not_Most_n <- length(DATA[which(DATA$MostCat != current_colour),
                                                                            which(names(DATA) == current_p)]) #extracting the number of participants who did not choose this colour as favourite
  CI2 <- CI(DATA[which(DATA$MostCat != current_colour), which(names(DATA) == current_p)]) # package Rmisc to calculate confidence intervals of the means of personality dimensions
  P_matrix[which(P_matrix$number == current_number),]$Not_Most_CI_lower <- CI2[3]
  P_matrix[which(P_matrix$number == current_number),]$Not_Most_CI_higher <- CI2[1]
  
  # stats (t-test, cohen's d, and Bayes factor)
  data_most <- (DATA[which(DATA$MostCat == current_colour),which(names(DATA) == current_p)]) #preparing a dataset
  data_not_most <- (DATA[which(DATA$MostCat != current_colour),which(names(DATA) == current_p)]) #preparing a dataset
  
  t_test <- t.test(data_most, data_not_most) #calculating t-test between participants who had a specific colour as their favourite (most) and those who have a different favourite colour (not_most)
  cohen <- cohen.d(data_most, data_not_most) #calculating cohen's d
  t_test_BF <- ttestBF(data_most, data_not_most, paired=FALSE, rscale=.707, nullInterval=c(0,+Inf)) #directional Bayesian stats with a prior of .707
  BF10 <- exp(t_test_BF@bayesFactor$bf[1]) #extracting Bayes factor
  
  P_matrix[which(P_matrix$number == current_number),]$t_value <- t_test$statistic
  P_matrix[which(P_matrix$number == current_number),]$p_value <- t_test$p.value
  P_matrix[which(P_matrix$number == current_number),]$d_value <- cohen$estimate
  P_matrix[which(P_matrix$number == current_number),]$d_CI_lower <- cohen$conf.int[1]
  P_matrix[which(P_matrix$number == current_number),]$d_CI_higher <- cohen$conf.int[2]
  P_matrix[which(P_matrix$number == current_number),]$BF_01 <- 1/BF10
  P_matrix[which(P_matrix$number == current_number),]$BF_10 <- BF10
  
}

# calculating one tail p-values (depending whether the direction of the effect is as expected or not)
p_calculator <- function(Most, Not_most, p_value_two_tail){ 
  if(Most > Not_most) {
      p_value_one_tail <- p_value_two_tail/2 } #when the effect goes to the expected direction
  else {
    p_value_one_tail <- 1- p_value_two_tail/2 #when the effect goes to the opposite than expected direction
  }
  p_value_one_tail
}

P_matrix$p_value_one_tail <- NA

for (current_number in P_matrix$number) {
  P_matrix[which(P_matrix$number == current_number),]$p_value_one_tail <- p_calculator(
                                                  P_matrix[which(P_matrix$number == current_number),]$Most_mean, 
                                                  P_matrix[which(P_matrix$number == current_number),]$Not_Most_mean, 
                                                  P_matrix[which(P_matrix$number == current_number),]$p_value)
}

#rounding up to input the values into the table
P_matrix$Most_CI_lower <- format(round(P_matrix$Most_CI_lower, 2), nsmall = 2)
P_matrix$Most_CI_higher <- format(round(P_matrix$Most_CI_higher, 2), nsmall = 2)
P_matrix$Most_mean <- format(round(P_matrix$Most_mean, 2), nsmall = 2)

P_matrix$Not_Most_CI_lower <- format(round(P_matrix$Not_Most_CI_lower, 2), nsmall = 2)
P_matrix$Not_Most_CI_higher <- format(round(P_matrix$Not_Most_CI_higher, 2), nsmall = 2)
P_matrix$Not_Most_mean <- format(round(P_matrix$Not_Most_mean, 2), nsmall = 2)

P_matrix$d_value <- format(round(P_matrix$d_value, 2), nsmall = 2)
P_matrix$d_CI_lower <- format(round(P_matrix$d_CI_lower, 2), nsmall = 2)
P_matrix$d_CI_higher <- format(round(P_matrix$d_CI_higher, 2), nsmall = 2)

P_matrix$Most_CI <- paste("[",P_matrix$Most_CI_lower,", ",P_matrix$Most_CI_higher,"]", sep = "")
P_matrix$Not_Most_CI <- paste("[",P_matrix$Not_Most_CI_lower,", ",P_matrix$Not_Most_CI_higher,"]", sep = "")
P_matrix$d_CI <- paste("[",P_matrix$d_CI_lower,", ",P_matrix$d_CI_higher,"]", sep = "")

P_matrix$t_value <- format(round(P_matrix$t_value, 2), nsmall = 2)
P_matrix$BF_01 <- format(round(P_matrix$BF_01, 2), nsmall = 2)
P_matrix$BF_10 <- format(round(P_matrix$BF_10, 2), nsmall = 2)

write.csv(P_matrix, "Planned_t_tests.csv", row.names = F)

P_matrix_short <- P_matrix[-c(8, 9, 12, 13, 16, 17, 18), -c(7,8,12,13,17,18)] #selecting columns of interest
P_matrix_short <- P_matrix_short[,c(1:13,16, 15, 14)] #reorder columns

# FDR correction for the p-values

P_matrix_short$p_value_one_tail_FDR <- p.adjust(P_matrix_short$p_value_one_tail, method = "fdr")
P_matrix_short$p_value <- format(round(P_matrix_short$p_value, 3), nsmall = 3)
P_matrix_short$p_value_one_tail <- format(round(P_matrix_short$p_value_one_tail, 3), nsmall = 3)
P_matrix_short$p_value_one_tail_FDR <- format(round(P_matrix_short$p_value_one_tail_FDR, 3), nsmall = 3)

write.csv(P_matrix_short, "Planned_t_tests_short.csv", row.names = F)


### ANOVAs Bayes factor #####

DATA$MostCat <- as.factor(DATA$MostCat)
DATA$LeastCat <- as.factor(DATA$LeastCat)

DATA$MostCatnew <- DATA$MostCat
DATA$MostCatnew <- revalue(DATA$MostCat, c("Yellow-Green" = "Other", "Brown" = "Other", "Grey" = "Other"))
DATA$MostCatnew <- droplevels(DATA$MostCatnew)
DATA$LeastCatnew <- DATA$LeastCat
DATA$LeastCatnew <- revalue(DATA$LeastCat, c("Red" = "Other", "Turquoise" = "Other", "Blue" = "Other", "White" = "Other"))
DATA$LeastCatnew <- droplevels(DATA$LeastCatnew)

# Models for Bayes factor calculation

sink('BayesFactorANOVA.txt') #writing results to text file

print("FAVOURITE COLOURS")
print("Conscientiousness")
bf <- anovaBF(Conscientiousness ~ MostCatnew, data=DATA)
print(bf)

print("Honesty")
bf <- anovaBF(Honesty ~ MostCatnew, data=DATA)
print(bf)

print("Agreeableness")
bf <- anovaBF(Agreeableness ~ MostCatnew, data=DATA)
print(bf)

print("Resilience")
bf <- anovaBF(Resilience ~ MostCatnew, data=DATA)
print(bf)

print("Extraversion")
bf <- anovaBF(Extraversion ~ MostCatnew, data=DATA)
print(bf)

print("Originality")
bf <- anovaBF(Originality ~ MostCatnew, data=DATA)
print(bf)

print("LEAST FAVOURITE COLOURS") 
print("Conscientiousness")
bf <- anovaBF(Conscientiousness ~ LeastCatnew, data=DATA)
print(bf)

print("Honesty")
bf <- anovaBF(Honesty ~ LeastCatnew, data=DATA)
print(bf)

print("Agreeableness")
bf <- anovaBF(Agreeableness ~ LeastCatnew, data=DATA)
print(bf)

print("Resilience")
bf <- anovaBF(Resilience ~ LeastCatnew, data=DATA)
print(bf)

print("Extraversion")
bf <- anovaBF(Extraversion ~ LeastCatnew, data=DATA)
print(bf)

print("Originality")
bf <- anovaBF(Originality ~ LeastCatnew, data=DATA)
print(bf)

sink()
